<?php
/**
 * WooCommerce UUID Test Plugin Functions
 *
 * @author   d.stanisheva
 * @package  woo-uuid
 * @since    1.0.0
 */
	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	if ( ! class_exists( 'Send_Data_Api_Icash' ) ) :

		/**
		 * Cart tab frontend class
		 */
		class Send_Data_Api_Icash {

			/**
			 * Setup class.
			 *
			 * @since 1.0.0
			 */
		        public $warehouseID;
			public $domain;
			public $api_key;
			public $secret_key;
			public $session_id;
			
			
			function microtime_float()
			{
			    $time = microtime();
			    list($usec, $sec) = explode(" ", $time);
			    $timeMS = ((float)$usec + (float)$sec) * 10000;
			    return $timeMS;
			}

			public function __construct() {
				$this->warehouseID    = get_option( 'warehouseid', true );
                		$this->domain         = get_option( 'domain', true );  

	        		$this->api_key        = get_option( 'api_key', true );
               			$this->secret_key     = get_option( 'secret_key', true );

				$nonce                = self::microtime_float();
                		$message              = $nonce.$this->warehouseID.$this->api_key;
				$signature            = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key, true)));
				
				//login
				$data = array(
					'api_key' => $this->api_key,
					'nonce' => $nonce,
					'signature' => $signature,
					'WareHouseID' => $this->warehouseID,
					'UserID' => 1);

			       // $url = 'http://nap.dev.icash.bg/clientapi/v1/login';

				$url = 'http://'.$this->domain.'/clientapi/v1/login';

				$response = wp_remote_post( $url , array('body' => $data ));

				if( is_wp_error( $response ) ) {
					return false; // Bail early
				}
				
				$responceData = json_decode(wp_remote_retrieve_body( $response ), TRUE );
		
				$this->session_id = $responceData['data']['session_id'];
			}
				
			
			public function getContragent($contragent){
			
				if(empty($contragent['company'])){
					$contragent['company'] = $contragent['first_name'].' '.$contragent['last_name'];
		    		}

				//find contragent
				$nonce     = self::microtime_float();
				$message   = $nonce.$this->warehouseID.$this->api_key;
				$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key, true)));
				$data = array(
			
					'ContragentMobile' => $contragent['phone'],
					'ContragentEmail' => $contragent['email'],
					'api_key' => $this->api_key,
					'nonce' => $nonce,
					'signature' => $signature,
					'ses' => strval($this->session_id)
				 );

				//$url = 'http://nap.dev.icash.bg/clientapi/v1/get-contragents';
				$url = 'http://'.$this->domain.'/clientapi/v1/get-contragents';

				$response = wp_remote_post( $url , array('body' => $data ));
				$responceContragent = json_decode(wp_remote_retrieve_body( $response ), TRUE );
				
				$contragentID = '';
				if(count($responceContragent['data']['Data']) == 1){
					$contragentID = $responceContragent['data']['Data'][0]['ContragentID'];

				}else{
		  			$nonce = self::microtime_float();
					$message = $nonce.$this->warehouseID.$this->api_key;
					$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));

					$data = array(
						'api_key' => $this->api_key,
						'nonce' 		  => $nonce,
						'signature' 		  => $signature,
						'ses' 			  => strval($this->session_id),
						'ContragentName'	  => $contragent['company'],
						'ContragentType'          => 'CLIENT',
						'ContragentCityName'      => $contragent['city'],
						'ContragentCountryCode'   => $contragent['country'],
						'ContragentAddress'       => $contragent['address_1'],
						'ContragentTaxNum' 	  => '',
						'ContragentVatRegistered' => 0,
						'ContragentMOL'		  => $contragent['first_name'].' '.$contragent['last_name'],
						'ContragentAllowPartPays' => 1,
						'ContragentForbidSupplies'=> 0,
						'ContragentForbidSales'   => 0,
						'ContragentPhone' 	  => $contragent['phone'],
						'ContragentFax' 	  => '',
						'ContragentWebSite'       => '',
						'ContragentMobile' 	  => $contragent['phone'],
						'ContragentEmail'         => $contragent['email']		
				       );
		 			//$url = 'http://nap.dev.icash.bg/clientapi/v1/add-contragent';

					$url = 'http://'.$this->domain.'/clientapi/v1/add-contragent';

					$response = wp_remote_post( $url , array('body' => $data ));
					$responceContragent = json_decode(wp_remote_retrieve_body( $response ), TRUE );

					if(count($responceContragent['data']) == 1){
						$contragentID = $responceContragent['data']['ContragentID'];
					}

				}
				
				return $contragentID;

			}

			public function getOnlineSettings(){
				//onlinesetting
				$nonce     = self::microtime_float();
				$message   = $nonce.$this->warehouseID.$this->api_key;
				$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));
				$data = array(
					'api_key' => $this->api_key,
					'nonce' => $nonce,
					'signature' => $signature,
					'ses' => strval($this->session_id)
				       );

				
				//$url = 'http://nap.dev.icash.bg/clientapi/v1/get-online-data';
				$url = 'http://'.$this->domain.'/clientapi/v1/get-online-data';

				$response = wp_remote_post( $url , array('body' => $data ));
				$responceOnlineData = json_decode(wp_remote_retrieve_body( $response ), TRUE );	

				return $responceOnlineData;
			}
			 
			public function newOperation($orderID, $contragentID, $storeID, $crID){
			//		new_operation

				$nonce = self::microtime_float();
				$message = $nonce.$this->warehouseID.$this->api_key;
				$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));
				$data = array(
					'api_key' => $this->api_key,
					'nonce' => $nonce,
					'signature' => $signature,
					'ses' => strval($this->session_id),
					'OperationType' => 'Sell',
					'ImportSource' => get_permalink( woocommerce_get_page_id( 'shop' ) ),
					'ImportRefID' => intval($orderID),
					'ContragentID' => $contragentID,
					'CashRegisterID' => intval($crID),
					'StoreID' => intval($storeID)
				       );

				//$url = 'http://nap.dev.icash.bg/clientapi/v1/new-operation';
				$url = 'http://'.$this->domain.'/clientapi/v1/new-operation';
		
				$response = wp_remote_post( $url , array('body' => $data ));
				$responceOperation = json_decode(wp_remote_retrieve_body( $response ), TRUE );
				$status = $responceOperation['status'];

				if( $status == 0){
					echo $responceOperation['data']['error_message'];
					if($responceOperation['data']['error_message'] == 'OFFLINE'){
						//wc_add_notice( __( 'Няма включена каса!' ), 'error' );

						return false;
					}else{
						//wc_add_notice( __( $responceOperation['data']['error_message'] ), 'error' );
						return false;
					}
				}
				
				$result = array();
				if(isset($responceOperation['data']['OperationID'])){
					$result['operationID'] = $responceOperation['data']['OperationID'];
					$result['uuid']= $responceOperation['data']['OperationFiskBonUUID'];
				}

				return $result;				
			}
			
			public function addOperationSaleItem($order, $operationID ){
				//operation sale items
			
				foreach ($order->get_items() as $item_key => $item ){
	
		       			$sale_item        = $item->get_product();
					$nonce 		  = self::microtime_float();
					$message 	  = $nonce.$this->warehouseID.$this->api_key;
					$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));
					
					$data = array(
						'api_key' => $this->api_key,
						'nonce' => $nonce,
						'signature' => $signature,
						'ses' => strval($this->session_id),
						'OperationID' => $operationID,
						'SaleItemInventoryID' => strval($sale_item->get_sku()),
						'Qty' => $item->get_quantity(),
						'SaleItemSinglePrice' => floatval($sale_item->get_price()),
						'SaleItemDiscount' => 0
					       );

					  //$url = 'http://nap.dev.icash.bg/clientapi/v1/add-operation-sale-item';
					  $url = 'http://'.$this->domain.'/clientapi/v1/add-operation-sale-item';

					  $response = wp_remote_post( $url , array('body' => $data ));
					  $responceOperationSaleItem = json_decode(wp_remote_retrieve_body( $response ), TRUE );
	
				  }
			}

			public function addShippingMethod($order, $operationID, $order_payment_method, $onlineSettings){
				echo $order_payment_method ;print_r($onlineSettings['data']['delivery']);
				if(in_array($order_payment_method,  $onlineSettings['data']['delivery'] )){
					$shipping_method = @array_shift($order->get_shipping_methods());

					$shipping_method_id = $shipping_method['method_id'];
					$shipping_name = $shipping_method['method_title'];
					$shipping_total = $order->get_total_shipping();
				
					//find shipping_method_id as saleitem 
					$nonce     = self::microtime_float();
					$message   = $nonce.$this->warehouseID.$this->api_key;
					$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key, true)));
					$data = array(						
						'api_key' 		=> $this->api_key,
						'nonce' 		=> $nonce,
						'signature' 		=> $signature,
						'ses' 			=> strval($this->session_id),
						'SaleItemInventoryID' 	=> strtoupper($shipping_method_id)
					 );

				
					$url = 'http://'.$this->domain.'/clientapi/v1/get-sale-items';

					$response = wp_remote_post( $url , array('body' => $data ));
					$responceShippingMethod = json_decode(wp_remote_retrieve_body( $response ), TRUE );
				
					$saleitemID= '';
					if($responceShippingMethod['status'] == 1 && $responceShippingMethod['data']['TotalRecords'] != 0){
						$saleitemID = $responceShippingMethod['data']['Data'][0]['SaleItemID'];

					}else{  
						// add ShippingMethod as saleitem

			  			$nonce = self::microtime_float();
						$message = $nonce.$this->warehouseID.$this->api_key;
						$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));

						$data = array(
							'api_key' 		  	=> $this->api_key,
							'nonce' 		  	=> $nonce,
							'signature' 		  	=> $signature,
							'ses' 			  	=> strval($this->session_id),
							'SaleItemInventoryID'	  	=> strtoupper($shipping_method_id),
							'SaleItemName'             	=> strval($shipping_name),
							'SaleItemCashRegisterName'      => strval($shipping_name),
							'SaleItemType'                 	=> 'SERVICE',
							'SaleItemPrimaryMeasureUnitID'  => 1,
							'SaleItemTaxGroupID' 	  	=> 2,
							'SaleItemSellPrice'       	=> $shipping_total,
							'SaleItemComment'	  	=> 'ShippingMethod from woocommerce'
						);
			 	
						$url = 'http://'.$this->domain.'/clientapi/v1/add-sale-item';

						$response = wp_remote_post( $url , array('body' => $data ));
						$responceShippingMethod = json_decode(wp_remote_retrieve_body( $response ), TRUE );
						if($responceShippingMethod['status'] == 1){
							$saleitemID = $responceShippingMethod['data']['SaleItemID'];
						}

					}
					 
					if(!empty(saleitemID)){
					     	$nonce 		  = self::microtime_float();
						$message 	  = $nonce.$this->warehouseID.$this->api_key;
						$signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));
					
						$data = array(
							'api_key' 	      => $this->api_key,
							'nonce'               => $nonce,
							'signature'           => $signature,
							'ses' 		      => strval($this->session_id),
							'OperationID'         => $operationID,
							'SaleItemID'  	      => $saleitemID,
							'Qty'                 => 1,
							'SaleItemSinglePrice' => floatval($shipping_total),
							'SaleItemDiscount'    => 0
						       );

						  
						  $url = 'http://'.$this->domain.'/clientapi/v1/add-operation-sale-item';

						  $response = wp_remote_post( $url , array('body' => $data ));
						  $responceOperationSaleItem = json_decode(wp_remote_retrieve_body( $response ), TRUE );

					}
				}
				
				
			}
			
			public function copmleteOperation( $operationID, $order_payment_method, $onlineSettings){
				$nonce = self::microtime_float();
			        $message = $nonce.$this->warehouseID.$this->api_key;
			        $signature = strtoupper(bin2hex(hash_hmac('sha256', $message, $this->secret_key,true)));
                 	
				if(in_array($order_payment_method,  $onlineSettings['data']['printreceipt'] )){
						
					
					$data = array(
						'api_key' => $this->api_key,
						'nonce' => $nonce,
						'signature' => $signature,
						'ses' => strval($this->session_id),
						'OperationID' => $operationID,
						'PayTypeID' => intval( $onlineSettings['data']['payTypeCode'][$order_payment_method])

					);

					//$url = 'http://nap.dev.icash.bg/clientapi/v1/print-operation';
					$url = 'http://'.$this->domain.'/clientapi/v1/print-operation';

					$response = wp_remote_post( $url , array('body' => $data ));
					$responcePrintOperation = json_decode(wp_remote_retrieve_body( $response ), TRUE );

					//print_r($responcePrintOperation);
				}else{
					
					$data = array(
						'api_key'   => $this->api_key,
						'nonce'     => $nonce,
						'signature' => $signature,
						'ses'       => strval($this->session_id),
						'OperationID' => $operationID,
						'PayTypeID' => intval( $onlineSettings['data']['payTypeCode'][$order_payment_method]),
						'PaymentBankAccountID' => $onlineSettings['data']['PaymentBankAccountID']

					);

					//$url = 'http://nap.dev.icash.bg/clientapi/v1/complete-operation';
					$url = 'http://'.$this->domain.'/clientapi/v1/complete-operation';
					$response = wp_remote_post( $url , array('body' => $data ));
					$responceCampleteOperation = json_decode(wp_remote_retrieve_body( $response ), TRUE );
                                        print_r($responceCampleteOperation);
				}
			
			
			}
			

		

		}

	endif;

   
					

