<?php
/**
 * WooCommerce UUID Test Plugin WC_Settings_Tab_Icash Class
 *
 * @author   d.stanisheva
 * @package  woo-uuid
 * @since    1.0.0
 */


	class WC_Settings_Tab_Icash {
	    /**
	     * Bootstraps the class and hooks required actions & filters.
	     *
	     */
	    public static function init() {
		add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
		add_action( 'woocommerce_settings_tabs_settings_tab_icash', __CLASS__ . '::settings_tab' );
		add_action( 'woocommerce_update_options_settings_tab_icash', __CLASS__ . '::update_settings' );
		add_action('woocommerce_process_product_meta', __CLASS__ . '::process_meta');
	    }


	    /**
	     * Add a new settings tab to the WooCommerce settings tabs array.
	     *
	     * @param array $settings_tabs Array of WooCommerce setting tabs & their labels, excluding the Subscription tab.
	     * @return array $settings_tabs Array of WooCommerce setting tabs & their labels, including the Subscription tab.
	     */
	    public static function add_settings_tab( $settings_tabs ) {
		$settings_tabs['settings_tab_icash'] = __( 'ICASH', 'woocommerce-settings-tab-icash' );
		return $settings_tabs;
	    }
	    /**
	     * Uses the WooCommerce admin fields API to output settings via the @see woocommerce_admin_fields() function.
	     *
	     * @uses woocommerce_admin_fields()
	     * @uses self::get_settings()
	     */
	    public static function settings_tab() {
		woocommerce_admin_fields( self::get_settings() );
	    }
	    /**
	     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
	     *
	     * @uses woocommerce_update_options()
	     * @uses self::get_settings()
	     */
	    public static function update_settings() {
		woocommerce_update_options( self::get_settings() );
	    }


		/**
	     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
	     *
	     * @uses woocommerce_update_options()
	     * @uses self::get_settings()
	     */
	    public static function process_meta() {

	    }


	    /**
	     * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
	     *
	     * @return array Array of settings for @see woocommerce_admin_fields() function.
	     */
	    public static function get_settings() {

	    		$settings[] = array( 'name' => __( 'Icash settings', 'text-domain' ), 
					     'type' => 'title', 
					     'desc' => __( 'The following options are to configure yours warehause in ICASH/V5', 'text-domain' ),
  					     'id' => 'wcslider' );

			// Add second text field option
			$settings[] = array(
			    'name'     => __( 'Domain', 'text-domain' ),
			    'desc_tip' => __( 'Choice the domain!', 'text-domain' ),
			    'id'       => 'domain',
			    'type'     => 'select',
			    'options' => array(
       					 'v5.icash.bg' 		=> 'v5',
        				 'e-sklad.bg' 		=> 'e-sklad',
					 'app.icash.bg' 	=> 'app.icash.bg',
					 'ibusiness.vivacom.bg' => 'vivacom',
					 'nap.dev.icash.bg' 	=> 'test'
					 ),
			);


		        $settings[] = array(
			    'name'     => __( 'WareHouse', 'text-domain' ),
			    'desc_tip' => __( 'Enter the number of your warehouse!', 'text-domain' ),
			    'id'       => 'warehouseid',
			    'type'     => 'number',
			);
			
			$settings[] = array(
			    'name'     => __( 'API key ICASH', 'text-domain' ),
			    'desc_tip' => __( 'Enter the Api key ADMIN of your warehouse!', 'text-domain' ),
			    'id'       => 'api_key',
			    'type'     => 'text',
			);

			$settings[] = array(
			    'name'     => __( 'Secret key ICASH', 'text-domain' ),
			    'desc_tip' => __( 'Enter the Secret key ADMIN of your warehouse!', 'text-domain' ),
			    'id'       => 'secret_key',
			    'type'     => 'text',
			);

		

			$settings[] = array( 'type' => 'sectionend', 'id' => 'icash' );
			

		return apply_filters( 'wc_settings_tab_icash_settings', $settings );
	    }
	}
	WC_Settings_Tab_ICASH::init();


